function plotallypx(y,opt)
%PLOTALLYPX Plot all the components of Y in different subplots

% This software is governed by the CeCILL-B license. You can  use,
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info/index.en.html". 

% Popixplore 1.0
% Marc Lavielle, Inria 
% May 2013

set(0,'defaultAxesTickDir','out')

ny=length(y);
n2=ceil(sqrt(ny));
n1=ceil(ny/n2);

for k=1:ny
    subplot(n1,n2,k)
    switch y{k}.type
        case 'continuous'
            scatidplot(y{k},opt)
        case 'categorical'
            catplot(y{k},opt)
        case 'event'
            kmplot(y{k},opt)
        case 'count'
            scatidplot(y{k},opt)
    end
end
set(0,'defaultAxesTickDir','in')

%%
function scatidplot(y,opt)
yh=y.header;
yn=y.name;
yu=y.unit;
iyx=opt.ix+2;
iyy=find(strcmp(yh,yn));
iyid=find(strcmp(yh,'iid'));
opt.yunit=yu{iyy};
opt.xunit=yu{iyx};
opt.xname=yh{iyx};
id=y.values(:,iyid);
xv=y.values(:,iyx);
yv=y.values(:,iyy);

N=length(unique(id));
hold off
for i=1:N
    j=find(id==i);
    xj=xv(j);
    yj=yv(j);
    if opt.segment==1
        plot(xj,yj,'.-')
    else
        plot(xj,yj,'.')
    end
    hold on
end

hold off
if ~isempty(opt.xunit)
    xlabel([opt.xname,' (',opt.xunit,')']);
else
    xlabel(opt.xname);
end
if ~isempty(y.unit)
    ylabel([y.name,' (',opt.yunit,')']);
else
    ylabel(y.name);
end
v=axis;
v(1:2) = [min(xv) max(xv)];
axis(v);

%%
function catplot(y,opt)
yh=y.header;
yn=y.name;
yu=y.unit;
iyx=opt.ix+2;
iyy=find(strcmp(yh,yn));
%iyid=find(strcmp(yh,'iid'));
opt.yunit=yu{iyy};
opt.xunit=yu{iyx};
opt.xname=yh{iyx};
%id=y.values(:,iyid);
X=y.values(:,iyx);
Y=y.values(:,iyy);

cy=unique(Y);
cx=unique(X);
ny=length(cy);
nx=length(cx);
C=zeros(nx,ny);
id=unique(y.values(:,1));
for j=1:nx
    ij= (X==cx(j));
    C(j,:)=hist(Y(ij),cy);
end
bar(cx,C,'stacked');
if ~isempty(opt.xunit)
    xlabel([opt.xname,' (',opt.xunit,')']);
else
    xlabel(opt.xname);
end
ylabel(['frequency (',y.name,')']);
lg=cell(1,ny);
for j=1:ny
    lg{j}=[y.name,' = ',y.category{j}];
end
legend(lg)


%%
function kmplot(y,opt)
yh=y.header;
yn=y.name;
yu=y.unit;
iyx=opt.ix+2;
iyy=find(strcmp(yh,yn));
iyid=find(strcmp(yh,'iid'));
opt.yunit=yu{iyy};
opt.xunit=yu{iyx};
opt.xname=yh{iyx};
ID=y.values(:,iyid);
T=y.values(:,iyx);
Ye=y.values(:,iyy);

[X,Y]=kmpx(ID,T,Ye);
tm=max([cell2mat(X(:,1)) ; cell2mat(X(:,2))]);

plot(X{2},Y{2})
v=axis;
v(2:3)=[tm -0.01];
axis(v)
if ~isempty(opt.xunit)
    xlabel([opt.xname,' (',opt.xunit,')']);
else
    xlabel(opt.xname);
end
ylabel('E(N(t))')


%%



