function plotpx(X,Y,G,ID,opt)
%PLOTPX Plot different types of data

% This software is governed by the CeCILL-B license. You can  use,
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info/index.en.html".

% Popixplore 1.0
% Marc Lavielle, Inria
% May 2013

set(0,'defaultAxesTickDir','out')

opt.ncat=length(opt.category);
opt.n1cat=ceil(sqrt(opt.ncat));
opt.n2cat=ceil(opt.ncat/opt.n1cat);
iopaxes=1;
switch opt.type
    case 'scatter'
        scatplot(X,Y,G,opt)
    case 'scatterid'
        scatidplot(X,Y,G,ID,opt)
    case 'cat'
        catplot(X,Y,G,opt)
  iopaxes=0;
  case 'boxplot'
        myboxplot(Y,X,G,opt)
  iopaxes=0;
  case 'bar'
        barplot(X,Y,G,opt)
  iopaxes=0;
  case'event'
        kmplot(X,Y,opt)
iopaxes=0;
end

if iopaxes==1
    vg=[Inf -Inf Inf -Inf];
    for k=1:opt.ncat
        subplot(opt.n1cat,opt.n2cat,k)
        xlim=get(gca,'xlim');
        ylim=get(gca,'ylim');
        vg=[min(xlim(1),vg(1)) max(xlim(2),vg(2)) min(ylim(1),vg(3)) max(ylim(2),vg(4))];
    end
    for k=1:opt.ncat
        subplot(opt.n1cat,opt.n2cat,k)
        axis(vg);
    end
end

set(0,'defaultAxesTickDir','in')

%%
function scatplot(X,Y,G,opt)
for k=1:opt.ncat
    subplot(opt.n1cat,opt.n2cat,k)
    ik=find(G==k);
    plot(X(ik),Y(ik),'.')
    if ~isempty(opt.xunit)
        xlabel([opt.xname,' (',opt.xunit,')']);
    else
        xlabel(opt.xname);
    end
    if ~isempty(opt.yunit)
        ylabel([opt.yname,' (',opt.yunit,')']);
    else
        ylabel(opt.yname);
    end
    if opt.ncat>1
        title([opt.gname,' = ',opt.glabel{k}],'fontsize',11)
    end
end

%%
function scatidplot(X,Y,G,ID,opt)
N=max(ID);
for k=1:opt.ncat
    subplot(opt.n1cat,opt.n2cat,k)
    hold off
    for i=1:N
        j=find(ID==i & G==k);
        if ~isempty(j)
            xj=X(j);
            yj=Y(j);
            if opt.segment==1
                plot(xj,yj,'.-')
            else
                plot(xj,yj,'.')
            end
            hold on
        end
    end
    hold off
    if ~isempty(opt.xunit)
        xlabel([opt.xname,' (',opt.xunit,')']);
    else
        xlabel(opt.xname);
    end
    if ~isempty(opt.yunit)
        ylabel([opt.yname,' (',opt.yunit,')']);
    else
        ylabel(opt.yname);
    end
    if opt.ncat>1
        title([opt.gname,' = ',opt.glabel{k}],'fontsize',11)
    end
end

%%
function catplot(X,Y,G,opt)
cy=unique(Y);
cx=unique(X);
ny=length(cy);
nx=length(cx);
C=zeros(nx,ny);
for k=1:opt.ncat
    subplot(opt.n1cat,opt.n2cat,k)
    ik=find(G==k);
    Xk=X(ik);
    Yk=Y(ik);
    for j=1:nx
        ij= (Xk==cx(j));
        C(j,:)=hist(Yk(ij),cy);
    end
    bar(cx,C,'stacked');
    if ~isempty(opt.xunit)
        xlabel([opt.xname,' (',opt.xunit,')']);
    else
        xlabel(opt.xname);
    end
    ylabel(['frequency (',opt.yname,')']);
    lg=cell(1,ny);
    for j=1:ny
        lg{j}=[opt.yname,' = ',opt.ylabel{j}];
    end
    legend(lg)
    
    if opt.ncat>1
        title([opt.gname,' = ',opt.glabel{k}],'fontsize',11)
    end
end

%%
function kmplot(X,Y,opt)
tm=max([cell2mat(X(:,1)) ; cell2mat(X(:,2))]);
nm=round(max(cell2mat(Y(:,2)))*10)/10 +0.1;
for k=1:opt.ncat
    if opt.repeated==1
        subplot(2,opt.ncat,k)
    else
        subplot(opt.n1cat,opt.n2cat,k)
    end
    plot(X{k,1},Y{k,1})
    v=axis;
    v(2:4)=[tm 0 1.05];
    axis(v)
    if ~isempty(opt.xunit)
        xlabel(['time (',opt.xunit,')']);
    else
        xlabel('time')
    end
    ylabel('P(T_1 > t)')
    if opt.ncat>1
        title([opt.gname,' = ',opt.glabel{k}],'fontsize',11)
    end
    
    if opt.repeated==1
        subplot(2,opt.ncat,opt.ncat+k)
        plot(X{k,2},Y{k,2})
        v=[0 tm -0.02 nm];
        axis(v)
        if ~isempty(opt.xunit)
            xlabel(['time (',opt.xunit,')']);
        else
            xlabel('time')
        end
       ylabel('E(N(t))')
  %      ylabel('cumulate number of events per individual')
    end
end

%%
function myboxplot(X,Y,G,opt)
for k=1:opt.ncat
    subplot(opt.n1cat,opt.n2cat,k)
    ik=find(G==k);
    boxplot(X(ik),Y(ik),'labels',opt.xlabel)
    xlabel(opt.xname);
    if ~isempty(opt.yunit)
        ylabel([opt.yname,' (',opt.yunit,')']);
    else
        ylabel(opt.yname);
    end
    if opt.ncat>1
        title([opt.gname,' = ',opt.glabel{k}],'fontsize',11)
    end
end

%%
function barplot(X,Y,G,opt)
maxB=0;
for k=1:opt.ncat
    subplot(opt.n1cat,opt.n2cat,k)
    %subplot(1,1,1)
    ik=find(G==k);
    Xk=X(ik);
    Yk=Y(ik);
    ux=unique(Xk);
    nx=length(ux);
    uy=unique(Yk);
    ny=length(uy);
    B=zeros(nx,ny);
    for j=1:nx
        ij=find(Xk==ux(j));
        B(j,:)=histc(Yk(ij),uy);
    end
    bar(B)
    xlabel(opt.xname);
    set(gca,'xticklabel',opt.xlabel)
    ylabel(['frequency (',opt.yname,')']);
    lg=cell(1,ny);
    for j=1:ny
        lg{j}=[opt.yname,' = ',opt.ylabel{j}];
    end
    legend(lg)
    if opt.ncat>1
        title([opt.gname,' = ',opt.glabel{k}],'fontsize',11)
    end
    maxB=max(maxB,max(B(:)));
end
for k=1:opt.ncat
    subplot(opt.n1cat,opt.n2cat,k)
    v=axis;
    v(4)=maxB+0.5;
    axis(v);
end



