function data = readdatapx(datafile,info)
%READDATAPX read a datafile and create a cell-array 

% This software is governed by the CeCILL-B license. You can  use,
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info/index.en.html". 

% Popixplore 1.0
% Marc Lavielle, Inria 
% May 2013

label=info.header;
iid=find(strcmp(label,'ID'));
itime=find(strcmp(label,'TIME'));
iamt=find(strcmp(label,'AMT'));
ixdose=find(strcmp(label,'XDOSE'));
iytype=find(strcmp(label,'YTYPE'));
iy=find(strcmp(label,'Y'));
ix=find(strcmp(label,'X'));
icov=find(strcmp(label,'COV'));
icat=find(strcmp(label,'CAT'));
imdv=find(strcmp(label,'MDV'));
ievid=find(strcmp(label,'EVID'));
iignore=find(strcmp(label,'IGNORE'));

nlabel=length(label);
fileFormat='';
if isstruct(datafile)
    if isfield(datafile, 'format')
        fileFormat=datafile.format;
    end
    datafile=datafile.name;
end
if isempty(fileFormat)
    [f,p,e]=fileparts(datafile);
    if strcmp(e,'.csv')
        fileFormat='csv';
    else
        fileFormat='\t';
    end
end
switch (lower(fileFormat))
    case {'csv'}
        delimiter=',';
    case {'space'}
        delimiter=' ';
    case {'tab'}
        delimiter='\t';
    case {';'}
        delimiter=';';
    otherwise
        delimiter=',';
end

%%
fid = fopen(datafile);
S0 = textscan(fid,'%s',nlabel,'delimiter',delimiter);
S0=S0{1};
fs=repmat('%s ',1,nlabel);
fs(3*(itime-1)+2)='f';
fs(3*(ix-1)+2)='f';
fs(3*(icov-1)+2)='f';
fs(3*(imdv-1)+2)='f';
fs(3*(ievid-1)+2)='f';

S = textscan(fid,fs,'delimiter',delimiter);
fclose(fid);

ls=zeros(1,nlabel);
for k=1:nlabel
    ls(k)=length(S{k});
end
lmin=min(ls);
for k=1:nlabel
    S{k}=S{k}(1:lmin);
end

%%
if isfield(info,'dose')
    dose=info.dose;
else
    dose=[];
end
if isfield(info,'observation')
    observation=info.observation;
else
    observation=struct;
end
nymax=10;
if ~isfield(observation,'name')
    observation.name=cell(1,nymax);
    for k=1:nymax
        eval(['observation.name{',num2str(k),'}=''y',num2str(k),''';'])
    end
end
if ~isfield(observation,'type')
    observation.type=cell(1,nymax);
    observation.type(:)={'continuous'};
end
if ~isfield(observation,'unit')
    observation.unit=cell(1,nymax);
    observation.unit(:)={''};
end
if isfield(info,'time')
    time=info.time;
else
    time.unit='';
end
if isfield(info,'regressor')
    regressor=info.regressor;
else
    regressor.unit=cell(1,length(ix));
end
if isfield(info,'covariate')
    covariate=info.covariate;
else
    covariate=[];
end

%%
[iduf,iuf,idnumf]=unique(S{iid},'first');
[ia,ib]=sort(iuf);
[~,ic]=sort(ib);
ids=iduf(ib);
iu=ia;
idnum=ic(idnumf);
N=length(iduf);

iop_id=0;
i=1;
while iop_id==0 && i<=N
    iop_id= strcmp(ids{i},num2str(i));
    i=i+1;
end

if iop_id
    id.name=S0{iid};
    id.label='id';
    id.value=ids;
    id={id};
end


if isempty(itime)
    itime=ix(1);
    ix=ix(2:end);
    time.unit=info.regressor.unit{1};
    info.regressor.unit=info.regressor.unit(2:end);
end
t=S{itime};
nx=length(ix);
reg_unit=cell(1,nx);

if nx>0
    iop_reg=1;
    lx=length(t);
    xx=zeros(lx,3+nx);
    for k=1:nx
        xx(:,3+k)=S{ix(k)};
    end
    xx(:,1)=idnum;
    xx(:,3)=t;
    xxu=unique(xx,'rows');
    idnumx=xxu(:,1);
    h=cumsum(hist(idnumx,0:N))';
    idobs=(1:length(idnumx))';
    xxu(:,2)=idobs-h(idnumx);
    reg_unit(:)={''};
    if isfield(info,'regressor') && isfield(info.regressor,'unit')
        iru=info.regressor.unit;
        reg_unit(1:length(iru))=iru;
        reg_unit=reg_unit(1:nx);
    end
    x=cell(1,nx);
    xxk=xxu(:,1:4);
    for k=1:nx
        x{k}.name=S0{ix(k)};
        x{k}.label='regressor';
        x{k}.level={'iid','iobs'};
        x{k}.header={'iid','iobs',S0{itime},S0{ix(k)}};
        x{k}.unit={'i', 'j', time.unit, reg_unit{k}};
        xxk(:,4)=xxu(:,3+k);
        x{k}.values=xxk;
    end
else
    iop_reg=0;
end

if ~isempty(iamt)
    ixdose=[iamt ixdose];
end
if ~isempty(ixdose)
    iop_source=1;
    if ~isempty(ievid)
        i1=find(~strcmp(S{ixdose(1)},'.') & S{ievid}>0 );
    else
        i1=find(~strcmp(S{ixdose(1)},'.'));
    end
    ndose=length(i1);
    nxdose=length(ixdose);
    dunit=cell(1,nxdose);
    dunit(:)={''};
    if isfield(dose,'unit')
        if ~iscell(dose.unit)
            dose.unit={dose.unit};
        end
        dunit(1:length(dose.unit))=dose.unit;
    end
    
    u.name='doseRegimen';
    u.label='source';
    u.level={'iid','isource'};
    u.header={'iid','isource',S0{itime},S0{ixdose}};
    u.unit=[{'i'},{'m'}, {time.unit},dunit];
          idu=idnum(i1);
        h=cumsum(hist(idu,0:N))';
        uv2=(1:length(idu))'-h(idu);
  uv=[idnum(i1) uv2 t(i1) zeros(ndose,length(ixdose))];
    
    for i=1:ndose
        for j=1:nxdose
            uv(i,3+j)=str2double(S{ixdose(j)}(i1(i)));
        end
    end
    u.values=uv;
    u={u};
else
    iop_source=0;
end

if ~isempty(imdv)
    iobs1=find(~strcmp(S{iy},'.') & S{imdv}==0 );
else
    iobs1=find(~strcmp(S{iy},'.'));
end
nobs=length(iobs1);
if nobs>0
    iop_obs=1;
    %   id1=idnum(iobs1);
    
    yvalues=[idnum(iobs1) (1:nobs)' t(iobs1) zeros(nobs,1+nx)] ;
    ytype=ones(nobs,1);
    for i=1:nobs
        yvalues(i,end)=str2double(S{iy}(iobs1(i)));
    end
    for j=1:nx
        for i=1:nobs
            yvalues(i,3+j)=S{ix(j)}(iobs1(i));
        end
    end
    if ~isempty(iytype)
        for i=1:nobs
            ytype(i)=str2double(S{iytype}(iobs1(i)));
        end
    end
    [yu,~,ytype]=unique(ytype);
    nyu=length(yu);
    
    y=cell(1,nyu);
    for k=1:nyu
        ik= (ytype==k);
        yvk=yvalues(ik,:);
        idk=yvk(:,1);
        h=cumsum(hist(idk,0:N))';
        idobs=(1:length(idk))';
        yvk(:,2)=idobs-h(idk);
        y{k}.name=observation.name{k};
        y{k}.label='observation';
        y{k}.level={'iid','iobs'};
        y{k}.type=observation.type{k};
        if strcmp(y{k}.type,'categorical')
            try
                y{k}.category = info.observation.category{k};
            catch
                yck=unique(yvk(:,end));
                y{k}.category = mat2cell(num2str(yck),ones(size(yck)));
            end
        end
        y{k}.header={'iid','iobs',S0{itime},S0{ix},y{k}.name};
        y{k}.unit=[{'i'},{'j'}, {time.unit}, reg_unit, observation.unit(k)];
        y{k}.values=yvk;
    end
else
    iop_obs=0;
end

ncov=length(icov);
ncat=length(icat);
nc=ncov+ncat;
if nc>0
    iop_cov=1;
    c=cell(1,nc);
   % i0=min([icov icat])-1;
    [icc,isc]=sort([icov icat]);
    iscov=isc(1:ncov);
    iscat=isc(ncov+1:nc);
    if ~isfield(covariate,'unit')
        covariate.unit=cell(1,nc);
    else
        cu=cell(1,nc);
        cu(1:length(covariate.unit))=covariate.unit;
        covariate.unit=cu;
    end
    for k=1:ncov
        ic=iscov(k);
        c{ic}.type='continuous';
        c{ic}.name=S0{icov(k)};
        c{ic}.values=[(1:N)' S{icov(k)}(iu)];
    end
    for k=1:ncat
        ic=iscat(k);
        [catnames,~,cc]=unique(S{icat(k)}(iu));
        c{ic}.type='categorical';
        c{ic}.name=S0{icat(k)};
        c{ic}.values=[(1:N)' cc];
        c{ic}.category=catnames(:)';
    end
    for k=1:nc
        c{k}.unit={'i',covariate.unit{k}};
        c{k}.label='covariate';
        c{k}.level={'iid'};
        c{k}.header={'iid', c{k}.name};
        if strcmp(c{k}.type,'continuous')
            c{k}=orderfields(c{k},{'name','label','type','level','header','unit','values'});
        else
            c{k}=orderfields(c{k},{'name','label','type','category','level','header','unit','values'});
        end
    end  
else
    iop_cov=0;
end

data=[];
if iop_id
    data=[data id];
end
if iop_reg
    data=[data x];
end
if iop_source
    data=[data u];
end
if iop_cov
    data=[data c];
end
if iop_obs
    data=[data y];
end


