function res=summarypx(c)
%SUMMARYPX Basic statistics of a set of covariates

% This software is governed by the CeCILL-B license. You can  use,
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info/index.en.html". 

% Popixplore 1.0
% Marc Lavielle, Inria 
% May 2013
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if ~isempty(c)
cname=cellfun(@(c)c.name,c,'uniformoutput',false);
ctype=cellfun(@(c)c.type,c,'uniformoutput',false);
j0=find(strcmp(ctype,'categorical'));
j1=find(strcmp(ctype,'continuous'));

v=cellfun(@(c)c.values,c,'uniformoutput',false);
cvalues=[v{:}];
cvalues=cvalues(:,2:2:end);
c0=cvalues(:,j0);
c1=cvalues(:,j1);

res.N=size(cvalues,1);

%%
if ~isempty(j1)
res.continuous=cname(j1);
    n1=length(j1);
    mean1=mean(c1,1);
    q1=prctile(c1,[25 50 75],1);
    std1=std(c1,1,1);
    min1=min(c1,[],1);
    max1=max(c1,[],1);
    res.mean=mean1;
    res.quartile=q1;
    res.std=std1;
    res.min=min1;
    res.max=max1;
    
    if n1>1;
        corr1=corrcoef(c1);
        res.corr=corr1;
    end
end
%%
if ~isempty(j0)
 res.categorical=cname(j0);
   n0=length(j0);
    f0=cell(1,n0);
    u0=cell(1,n0);
    for j=1:n0
        c0j=c0(:,j);
        u0{j}=unique(c0j);
        f0{j}=histc(c0j,u0{j})';
    end
    res.freq=f0;
    
    if n0>1
        cd0=cell(n0,n0);
        for j=1:n0
            c0j=c0(:,j);
            u0j=u0{j};
            nj=length(u0j);
            for m=1:nj
                im= (c0j==u0j(m));
                c0m=c0(im,:);
                for k=1:n0
                    c0jk=c0m(:,k);
                    fjk=histc(c0jk,u0{k});
                    cd0{j,k}(m,:)=fjk/sum(fjk);
                end
            end
        end
        res.cdist=cd0;
    end
end
else
    res=[];
end

